@@ -226,7 +226,7 @@ pub static FUNCTIONS: phf::Map<&'static str, WFunc> = phf_map! {
     "reverse" => reverse,
     "OUTPUT" => output,
     "eq" => eq,
-    "if-else" => if_else,
+    "if" => if_else,
     "expand" => expand,
     "release" => release,
     "bundle" => bundle
